
.. _ref_bases:

Abstract Classes
================

Template
--------

.. autoclass:: redbird.templates.TemplateRepo
    :members:

.. autoclass:: redbird.templates.TemplateResult
    :members:

Base Classes
------------

.. autoclass:: redbird.base.BaseRepo
    :members:

.. autoclass:: redbird.base.BaseResult
    :members:

